@@ -4,11 +4,6 @@
 # Licence GPL v3
 
 
-if (!isGeneric("mask")) {
-	setGeneric("mask", function(x, mask, ...)
-		standardGeneric("mask"))
-}	
-
 
 setMethod('mask', signature(x='Raster', mask='sf'), 
 function(x, mask, ...) {
@@ -20,8 +15,12 @@ function(x, mask, ...) {
 
 setMethod('mask', signature(x='Raster', mask='Spatial'), 
 function(x, mask, filename="", inverse=FALSE, updatevalue=NA, updateNA=FALSE, ...){ 
-	mask <- rasterize(mask, x, 1, silent=TRUE)
-	mask(x, mask, filename=filename, inverse=inverse, maskvalue=NA, updatevalue=updatevalue, ...)
+	if (inherits(mask, 'SpatialPolygons')) {
+		m <- .fasterize(mask, x, values=rep(1,length(mask)))
+	} else {
+		m <- rasterize(mask, x, 1, silent=TRUE)
+	}
+	mask(x, m, filename=filename, inverse=inverse, maskvalue=NA, updatevalue=updatevalue, ...)
 } )
 
 
